@@ -10,7 +10,8 @@ from siegfried import (
 
 from libs import feedparser
 from util import (
-  get_jsonpath, strip_tags, parse_datetime, imgs_from_html, utc_now
+  get_jsonpath, strip_tags, parse_datetime, 
+  imgs_from_html, utc_now, logger
   )
 
 try:
@@ -31,8 +32,16 @@ else:
 try:
   import gevent
   from gevent.pool import Pool
+
+  # patch everything except for thread.
   import gevent.monkey
-  gevent.monkey.patch_all()
+  gevent.monkey.patch_socket()
+  gevent.monkey.patch_ssl()
+  gevent.monkey.patch_os()
+  gevent.monkey.patch_time()
+  gevent.monkey.patch_select()
+  gevent.monkey.patch_subprocess()
+
 except ImportError:
   imported_gevent = False
 else:
@@ -80,19 +89,13 @@ class SupeRSS:
     self.feed = feed
     self.homepage = homepage
     self.concurrent = kwargs.get('concurrent', False)
-    if self.concurrent:
-      if not imported_gevent:
-        raise SupeRSSInitError(
-          'SupeRSS requires gevent to run concurrently.'
-          )
-      else:
-        self.pool = Pool(kwargs.get('num_workers', 10))
+    self.num_workers = kwargs.get('num_workers', 20)
+    self.is_full_text = kwargs.get('is_full_text', True)
 
     # if we haven't import particle, assume we have the full text
-    if imported_particle:
-      self.is_full_text = kwargs.get('is_full_text', False)
-    else:
-      self.is_full_text = True
+    if self.is_full_text and not imported_particle:
+      logger.warn('SupeRSS requires particle to get extract articles')
+      self.is_full_text = False
 
     if self.homepage:
       if not imported_particle or not imported_pageone:
@@ -271,9 +274,17 @@ class SupeRSS:
     return self.merge_extracted_data(entry, extracted_data)
 
   def run_concurrent(self, func, iterator):
+    pool = Pool(self.num_workers)
     if self.concurrent:
-      for result in self.pool.imap_unordered(func, iterator):
-        yield result 
+      if imported_gevent:
+        for result in pool.imap_unordered(func, iterator):
+          yield result 
+
+      else:
+        logger.warn('SupeRSS requires gevent run concurrently.')
+        for item in iterator:
+          yield func(item)
+
     else:
       for item in iterator:
         yield func(item)
@@ -296,7 +307,6 @@ class SupeRSS:
     p = Particle()
     return self.run_concurrent(p.extract, pg1.articles())
 
-
   def run(self):
     """
     run different methods based on intialization parameters
