@@ -4,6 +4,10 @@ import re
 import pytz 
 import jsonpath_rw as jsonpath
 from bs4 import BeautifulSoup
+import logging
+
+logging.basicConfig()
+logger = logging.getLogger("superss")
 
 # html stripping
 class MLStripper(HTMLParser):
